# withrepo
Pythonic access to git repositories

## TODO

- [ ] Support gitlab (public)
- [ ] Support bitbucket (public)

- [ ] Support github (private)
- [ ] Support gitlab (private)
- [ ] Support bitbucket (private)

- [ ] Support filesystem caching
- [ ] Support explicit init for filesystem caching (for APIs, workers, etc.)
- [ ] Investigate read-only mode
- [ ] Readme